from ekp_sdk.util.clean_null_terms import clean_null_terms


def Icon(name, class_name=None, size=None):
    return {
        "_type": "Icon",
        "props": clean_null_terms({
            "className": class_name,
            "name": name,
            "size": size
        })
    }


import asyncio
import time


class Limiter():
    def __init__(self, min_time_ms, max_concurrent):
        self.min_time_ms = min_time_ms
        self.max_concurrent = max_concurrent
        self.last_request = 0
        self.open = 0


    async def acquire(self):
        while True:
            now = time.perf_counter()

            if ((now - self.last_request) >= (self.min_time_ms / 1000) and (self.open < self.max_concurrent)):
                self.last_request = now
                self.open += 1
                break

            await asyncio.sleep(0.01)

    def release(self):
        self.open -= 1



from ekp_sdk.services.cache_service import CacheService
from ekp_sdk.services.client_service import ClientService
from ekp_sdk.services.coingecko_service import CoingeckoService
from ekp_sdk.services.etherscan_service import EtherscanService
from ekp_sdk.services.limiter import Limiter
from ekp_sdk.services.redis_client import RedisClient
from ekp_sdk.services.rest_client import RestClient
from ekp_sdk.services.transaction_sync_service import TransactionSyncService
from ekp_sdk.services.web3_service import Web3Service
from ekp_sdk.services.base_mapper_service import BaseMapperService
from ekp_sdk.services.moralis_api_service import MoralisApiService
from ekp_sdk.services.google_sheets_client import GoogleSheetsClient


from ekp_sdk.ui.rpc.commify import *
from ekp_sdk.ui.rpc.format_mask_address import *
from ekp_sdk.ui.rpc.navigate import *
from ekp_sdk.ui.rpc.remove_form_record import *
from ekp_sdk.ui.rpc.sum import *
from ekp_sdk.ui.rpc.count import *
from ekp_sdk.ui.rpc.ekp_map import *
from ekp_sdk.ui.rpc.format_age import *
from ekp_sdk.ui.rpc.format_currency import *
from ekp_sdk.ui.rpc.format_datetime import *
from ekp_sdk.ui.rpc.format_percent import *
from ekp_sdk.ui.rpc.format_template import *
from ekp_sdk.ui.rpc.is_busy import *
from ekp_sdk.ui.rpc.json_array import *
from ekp_sdk.ui.rpc.sort_by import *
from ekp_sdk.ui.rpc.switch_case import *



from ekp_sdk.util.clean_null_terms import clean_null_terms


def Column(
    id,
    cell=None,
    format=None,
    grow=None,
    omit=None,
    min_width=None,
    right=None,
    searchable=None,
    sortable=None,
    title=None,
    value=None,
    width=None,
):
    return clean_null_terms({
        "cell": cell,
        "format": format,
        "grow": grow,
        "id": id,
        "minWidth": min_width,
        "omit": omit,
        "right": right,
        "searchable": searchable,
        "sortable": sortable,
        "title": title,
        "value": value,
        "width": width,
    })


from ekp_sdk.util.clean_null_terms import clean_null_terms


def Col(class_name=None, children=None, when=None):
    return {
        "_type": "Col",
        "props": clean_null_terms({
            "className": class_name,
            "children": children or [],
            "when": when
        })
    }


from ekp_sdk.util.clean_null_terms import clean_null_terms


def Card(children=None, class_name=None):
    return {
        "_type": "Card",
        "props": clean_null_terms({
            "children": children,
            "className": class_name
        })
    }